@@ -59,6 +59,8 @@ class Workbook(xmlwriter.XMLwriter):
         self.tmpdir = options.get('tmpdir', None)
         self.date_1904 = options.get('date_1904', False)
         self.strings_to_numbers = options.get('strings_to_numbers', False)
+        self.strings_to_formulas = options.get('strings_to_formulas', True)
+        self.strings_to_urls = options.get('strings_to_urls', True)
         self.default_date_format = options.get('default_date_format', None)
         self.worksheet_meta = WorksheetMeta()
         self.selected = 0
@@ -103,6 +105,10 @@ class Workbook(xmlwriter.XMLwriter):
         # Add the default cell format.
         self.add_format({'xf_index': 0})
 
+        # Add a default URL format.
+        self.default_url_format = self.add_format({'color': 'blue',
+                                                   'underline': 1})
+
         # Add the default date format.
         if self.default_date_format is not None:
             self.default_date_format = \
@@ -137,7 +143,10 @@ class Workbook(xmlwriter.XMLwriter):
             'tmpdir': self.tmpdir,
             'date_1904': self.date_1904,
             'strings_to_numbers': self.strings_to_numbers,
+            'strings_to_formulas': self.strings_to_formulas,
+            'strings_to_urls': self.strings_to_urls,
             'default_date_format': self.default_date_format,
+            'default_url_format': self.default_url_format,
         }
 
         worksheet = Worksheet()
@@ -492,13 +501,19 @@ class Workbook(xmlwriter.XMLwriter):
 
     def _set_default_xf_indices(self):
         # Set the default index for each format. Only used for testing.
+
+        formats = list(self.formats)
+
+        # Delete the default url format.
+        del formats[1]
+
+        # Skip the default date format if set.
         if self.default_date_format is not None:
-            # Skip initialising format[1] if there is a default date format.
-            for xf_format in self.formats[:1] + self.formats[2:]:
-                xf_format._get_xf_index()
-        else:
-            for xf_format in self.formats:
-                xf_format._get_xf_index()
+            del formats[1]
+
+        # Set the remaining formats.
+        for xf_format in formats:
+            xf_format._get_xf_index()
 
     def _prepare_fonts(self):
         # Iterate through the XF Format objects and give them an index to
